#!/bin/sh
#
# Check id self ID is set and obtains one if necessary.
#
#   createselfid.sh [-d]
#
# Determines self ID in the following order:
#   1./ [Deprecated] If there is a parent configured uses the device id for this host used by the parent
#   2./ [Deprecated] If there is any child configured uses the device id for this host used by one of the child servers
#   3./ Uses `hostname -s`
#
# Unless -d option is specified only the last (#3) step will be used.
# This will suite for new installs and servers upgraded from 6.x or even 5.1 (and having the serverid already set). 
#
# We assume upgrading older servers directly to v7.0 is not a valid scenario (breaking procedures), but to keep the
# ability to get the serverid from parent/child servers the -d option has been introduced to let the deprecated modes
# be called from command line by support if needed 
#
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

UseDeprecated="false"

[ "$1" = "-d" ] && UseDeprecated="true"

getIDFromDevice_()
{
	[ -z "$1" ] && return 1
	HOST=`echo "select HOST from $TARGETTBL where ID='$1';" | \
			$MYSQL_HOME/bin/mysql -N $DBNAME 2>/dev/null`
	[ -z "$HOST" ] && return 1

	RES=`$CURL_HOME/bin/curl -s "http://$HOST/dotcom/getpeerid.jsp"`
	awk -vFS="=" '($1 == "DeviceID") {print $2}' <<<"$RES"
}


[ -f "$CONF/serverid.cfg" ] && exit 0

SelfServerID=""

if [ "true" = "$UseDeprecated" ] ; then
	DevIDs=`echo "select ID from $TARGETTBL where TYPE='C' OR TYPE='P' order by TYPE desc, ID;" | \
			$MYSQL_HOME/bin/mysql -N $DBNAME 2>/dev/null`

	for dev in $DevIDs ; do
		[ -n "$SelfServerID" ] && continue
		SelfServerID=`getIDFromDevice_ "$dev"`
	done
fi

if [ -z "$SelfServerID" ] ; then
	SelfServerID=`hostname -s`
fi

cat <<-ENDOFSELFIDREC > $CONF/serverid.cfg.$$
	# This is an autogenerated file
	# DO NOT EDIT !!!!
	#
	# IF YOU NEED TO CHANGE THE VALUE OF SELF_SERVER_ID CONTACT THE DEVELOPMENT TEAM FIRST !!!!
	#

	SELF_SERVER_ID="$SelfServerID"
ENDOFSELFIDREC

chmod a-w $CONF/serverid.cfg.$$
mv $CONF/serverid.cfg.$$ $CONF/serverid.cfg 2>/dev/null
[ -f "$CONF/serverid.cfg.$$" ] && rm -f $CONF/serverid.cfg.$$

