#!/bin/sh
#
# Component: iface/scheduler
#
# Purpose:
#     Handles SCHEDULERMSG released events
#
# Usage:
#    onSchedulerMsgReleased.sh -t <type> -e <event> -i <id>
#
#    -t type  : Object type to be released. It will always be "SCHEDULERMSG"
#    -e event : Event triggered runiing this script. It will always be "RELASED"
#    -i id    : Identifies the HL7 message (=<filename>)
#
# Description:
#     Will be called when a SCHEDULERMSG reference counter is released.
# The HL7 message file from ${SCHEDULER_MSGFLAG_DIR} will be deleted
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh


# onObjectfileReleased.sh can be called directly:
# run as a task instead
if [ `basename $0` = "onSchedulerMsgReleased.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi


LOGGER="/usr/bin/logger"
TAG="onSchedulerMsgReleased.sh[$$]"

object=""
type=""
event=""
errMsg=""

while getopts 'e:t:i:' OPT; do
	case $OPT in
	e) event="$OPTARG" ;;
	t) type="$OPTARG" ;;
	i) object="$OPTARG" ;;
	*) errMsg="Invalid_Parameter:$OPT" ;;
	esac
done

run_()
{
	if [ "$type" != "SCHEDULERMSG" -o "$event" != "RELEASED" -o -z "$object" -o -n "$errMsg" ] ; then
		$LOGGER -p $LOG_FACILITY.err -t "$TAG" "Invalid argument: Type: $type; Event: $event; Objectfile: $object; $errMsg"
		return 125;
	fi

	# remove $object from the ${HL7_MSGFLAG_DIR}
	rm -f ${SCHEDULER_MSGFLAG_DIR}/${object} 2>/dev/null
}

# override print_
print_()
{
	echo "Handles Scheduler Message released event: Type: $type; Event: $event: Object: $object"
}

#
# default get display name (for subjob)
#
get_display_name_()
{
	echo "Releases message sent to the Scheduler module"
}



# override get_watson_message_
get_watson_message_()
{
	[ -z "$DR_WATSON_ID" ] && DR_WATSON_ID="onschedulermsgreleased.$object"
	[ -z "$DR_WATSON_MESSAGE" ] && DR_WATSON_MESSAGE="handling scheduler message released event: $object"

	if [ "$RUN_RESULT" -gt 124 ] ; then
		WATSON_MESSAGE_ID="$DR_WATSON_ID.failed"
		WATSON_MESSAGE_TEXT="FAILED: $DR_WATSON_MESSAGE"
		return
	fi

	if [ "$RUN_RESULT" -ne 0 -a "$RETRY_NUM" -gt 0 -a $(( $RETRY_NUM % 10)) -eq 0 ] ; then
		WATSON_MESSAGE_TEXT="ERROR: $DR_WATSON_MESSAGE [Retry #$RETRY_NUM]"
		WATSON_MESSAGE_ID="$DR_WATSON_ID.$RETRY_NUM"
	fi
} # get_watson_message_()

